# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2007, 2008. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

# import related classes
import sys;
from java.lang import *;
import java.io.File as File;
import re;

#------------------------------------------------------------------------------
# get the property value by the the property name; If property not available, return ''
#------------------------------------------------------------------------------
def getPropertyValue(propertyName):
	propertyValue = java.lang.System.getProperty(propertyName);
	if(propertyValue == None):
		return '';
	return propertyValue;
#endDef

#-----------------------------------------------------------------
# Logs messages
#-----------------------------------------------------------------
def trace(message):
    print message;
#endDef

def normalizePath(pathName):
	newPath=File(pathName);
	return newPath.getAbsolutePath();
#endDef


#------------------------------------------------------------------------------
# get the cell name
#------------------------------------------------------------------------------
def getCellName():
	return getPropertyValue('local.cell');
#endDef

#------------------------------------------------------------------------------
# get the node name
#------------------------------------------------------------------------------
def getNodeName():
	return getPropertyValue('local.node');
#endDef

#------------------------------------------------------------------------------
# get the node type: managed,unmanaged,
#------------------------------------------------------------------------------
def getNodeType():
	return getPropertyValue('wbi.upgrade.node.type');
#endDef

#--------------------------------------------------------------
# Get a value of WPSHOME.that is migrated to.
#--------------------------------------------------------------
def getWASHome():
	return getPropertyValue('was.install.root');
#endDef


#--------------------------------------------------------------
# Get a value of WPSHOME.that is migrated to.
#--------------------------------------------------------------
def getProfileHome():
	return getPropertyValue('user.install.root');
#endDef
#--------------------------------------------------------------
# Helper Class to normalize the string for comparision
#--------------------------------------------------------------
def wsadminToList(inStr):
	outList=[]
	if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
		tmpList = inStr[1:-1].split() #splits space-separated lists,
	else:
		tmpList = inStr.split("\n")   #splits for Windows or Linux
	for item in tmpList:
		item = item.rstrip();         #removes any Windows "\r"
		if (len(item)>0):
			outList.append(item)
	return outList;
#endDef

#------------------------------------------------------------------------------
# get the scope Id according to cellname ,nodename, servername, clustername
#------------------------------------------------------------------------------
def getScopeId(cellName,nodeName,serverName,clusterName):
	trace("****************getScopeId() start****************");
	scopeId="";
	if (cellName ==''):
		scopeId='';
	elif (nodeName ==''):
		scopeId=AdminConfig.getid('/Cell:' + cellName);
	elif (serverName == '' and clusterName == ''):
		scopeId=AdminConfig.getid('/Cell:' + cellName + '/Node:' + nodeName);
	elif (serverName == ''):
		scopeId=AdminConfig.getid('/Cell:' + cellName + '/ServerCluster:' + clusterName);
	else:
		scopeId=AdminConfig.getid('/Cell:' + cellName + '/Node:' +nodeName + '/Server:' + serverName);
	#endIf
	trace("****************getScopeId() end****************");
	return scopeId;
#endDef

def getExactScopeId(Id,cellName,nodeName,serverName, clusterName):
	# get exact variable which is only located in  cell ,node or server or cluster level.
	filteredId="";
	if(cellName == ""):
		filteredId="";
	elif(nodeName == ""):
		filteredId=locateId(Id,"cell");
	elif(serverName == "" and clusterName == ""):
		filteredId=locateId(Id,"node");
	elif(clusterName==""):
		filteredId=locateId(Id,"server");
	else:
		filteredId=locateId(Id,"cluster");

	#endIf
	
	return filteredId;
#endDef

#---------------------------------------------------------------------------------------------------------------
# locate resource in cell , node or server level.
#---------------------------------------------------------------------------------------------------------------
def locateId(element,scopeLevel):
	if ( scopeLevel == "cell" ):
		#cell level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(nodes).*",element) == None and
			re.search(".*(clusters).*",element) == None and
			re.search(".*(servers).*",element) == None):
			return element;
		else:
			return "";
		#endIf
	elif ( scopeLevel == "node" ):
		#node level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(nodes).*",element) != None and
			re.search(".*(clusters).*",element) == None and
			re.search(".*(servers).*",element) == None):
			return element;
		else:
			return "";
		#endIf
	elif ( scopeLevel == "server" ):
		#server level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(clusters).*",element) == None and
			re.search(".*(nodes).*",element) != None and
			re.search(".*(servers).*",element) != None):
			return element;
		else:
			return "";
		#endIf
	elif ( scopeLevel == "cluster" ):
		#cluster level
		if ( re.search(".*(cells).*",element) != None and
			re.search(".*(clusters).*",element) != None and
			re.search(".*(nodes).*",element) == None and
			re.search(".*(servers).*",element) == None):
			return element;
		else:
			return "";
		#endIf
	else:
		return "";
	#endIf
#endDef

#--------------------------------------------------------------------------------------------------------------------------------------------
# get a value of  WPSHOME.that is migrated.
# main logic:
# get MigratedWASHOME from ${backupDir}/websphere_backup/properties/profileRegistry.xml file.
#---------------------------------------------------------------------------------------------------------------------------------------------
def getMigratedWASHome():
	trace("****************getMigratedWASHome() start****************");
	backupDir=getBackupDir();
	trace("wbi migration backup dir:"+backupDir);
	profileRegistryFile=backupDir+File.separator+"websphere_backup"+File.separator+"properties"+File.separator+"profileRegistry.xml";
	sourceFile=open(profileRegistryFile,"r");
	srclines=sourceFile.readlines();
	sourceFile.close();
	for srcline in srclines :
		# trace(srcline);
		foundString='template="';
		foundStringLen=len(foundString);
		startIndex=srcline.find(foundString);
		if(startIndex!=-1):
			endIndex=srcline.find('">',startIndex+foundStringLen);
			templatePath=srcline[startIndex+foundStringLen:endIndex];
			trace("templatePath: "+templatePath);
			foundTemplatePathString="profileTemplates";
			templatePathStartIndex=templatePath.find(foundTemplatePathString);
			wasHome=templatePath[0:templatePathStartIndex - 1];
			trace("WASHOME: "+wasHome);
			break;
		#endIf
	#endFor
	trace("****************getMigratedWASHome() end****************");
	return wasHome;
#endDef

#--------------------------------------------------------------------------------------------------------------------------------------------
# get a value of  Profile HOME.that is migrated.
# main logic:
# get MigratedWASHOME from ${backupDir}/websphere_backup/properties/profileRegistry.xml file.
#---------------------------------------------------------------------------------------------------------------------------------------------
def getMigratedProfileHome():
	trace("****************getMigratedProfileHome() start****************");
	previousProfileName = System.getProperty("bpm.upgrade.previous.profileName");
	backupDir=getBackupDir();
	trace("wbi migration backup dir:"+backupDir);
	trace("previousProfileName " + previousProfileName);
	profileRegistryFile=backupDir+File.separator+"websphere_backup"+File.separator+"properties"+File.separator+"profileRegistry.xml";
	sourceFile=open(profileRegistryFile,"r");
	srclines=sourceFile.readlines();
	sourceFile.close();
	profileHome = ""
	for srcline in srclines :
		trace(srcline);
		foundString='name="' + previousProfileName;
		foundStringLen=len(foundString);
		startIndex=srcline.find(foundString);
		if(startIndex!=-1):
			startIndex = srcline.find('path="');
			endIndex=srcline.find('"',startIndex+6);
			templatePath=srcline[startIndex+6:endIndex];
			trace("Path: "+templatePath);
			profileHome = templatePath
			trace("ProfileHOME: "+templatePath);
			break;
		#endIf
	#endFor
	trace("****************getMigratedProfileHome() end****************");
	return profileHome;
#endDef


#--------------------------------------------------------------
# Get Backup Folder for Migrtaing WPS Profile
#--------------------------------------------------------------
def getBackupDir():
	return getPropertyValue('wbi.upgrade.backup.dir');
	#return "E:\\backup601";
#endDef

#---------------------------------------------------------------------------
# convert 60x variable to 70 variable:
# for example:   
# c:/wps601/profiles/proc1 ---> c:/wps70/profiles/proc1
#----------------------------------------------------------------------------
def convertProfilePathFrom6xTo70(variable60x):
	trace("****************convertProfilePathFrom6xTo70() start****************");
	
	migratedProfileHome=normalizePath(getMigratedProfileHome());
	migratedProfileHome=migratedProfileHome.replace('\\',"/");
	trace("migratedProfileHome:"+migratedProfileHome);
	
	#the location of 61 was root home
	presentProfileHome=getProfileHome();
	#presentWPSHome=presentProfileHome.replace('\\',"/");
	trace("presentProfileHome:"+presentProfileHome);
	
	#convert a variable of 60x to  a new variable of 61.
	variable61="";
	#fix the delimiter
	variable60xnew = variable60x.replace('\\', "/");
	trace("variable60xnew:"+variable60xnew);
	if (variable60xnew.find(migratedProfileHome)!=-1):
		foundStringLenMigratedProfileHome=len(migratedProfileHome);
		#check for the variable length itself
		variablelength = len(variable60x);
		if (variablelength == foundStringLenMigratedProfileHome):
		    trace("length is matching");
		    if (migratedProfileHome == variable60xnew):
		    		trace("value is matching");
				variable61 = presentProfileHome;
				trace("original value:"+variable60xnew);
				trace("replaced value:"+variable61);
		    else:
				variable61 = variable60x;
		    #endIf
		else:
			str = variable60xnew[0:foundStringLenMigratedProfileHome+1]
			if ( (migratedProfileHome+"/"  == str) or (migratedProfileHome+"\\"  == str)  ):
				trace("value matching found");
				variable61=variable60xnew.replace(migratedProfileHome,presentProfileHome);
				trace("original value:"+variable60xnew);
				trace("replaced value:"+variable61);
			else: 
				variable61=variable60x;
			#endIf
		#endIf
	else:
		variable61=variable60x;
	
	#endIf
	trace("Value being returned " + variable61);
	return variable61;
#endDef

def convertPathFrom6xTo70(variable60x):
	# the location of 60x was root home 
	migratedWPSHome=normalizePath(getMigratedWASHome());
	migratedWPSHome=migratedWPSHome.replace('\\',"/");
	trace("migratedWPSHome:"+migratedWPSHome);
	
	#the location of 61 was root home
	presentWPSHome=getWASHome();
	#presentWPSHome=presentWPSHome.replace('\\',"/");
	trace("presentWPSHome:"+presentWPSHome);
	
	#convert a variable of 60x to  a new variable of 61.
	variable61="";
	#fix the delimiter
	variable60xnew = variable60x.replace('\\', "/");
	trace("variable60xnew:"+variable60xnew);
	if (variable60xnew.find(migratedWPSHome)!=-1):
		foundStringLenMigratedWPSHome=len(migratedWPSHome);
		#check for the variable length itself
		variablelength = len(variable60x);
		if (variablelength == foundStringLenMigratedWPSHome):
		    trace("length is matching");
		    if (migratedWPSHome == variable60xnew):
		    		trace("value is matching");
				variable61 = presentWPSHome;
				trace("original value:"+variable60xnew);
				trace("replaced value:"+variable61);
		    else:
				variable61 = variable60x;
		    #endIf
		else:
			str = variable60xnew[0:foundStringLenMigratedWPSHome+1]
			if ( (migratedWPSHome+"/"  == str) or (migratedWPSHome+"\\"  == str)  ):
				trace("value matching found");
				variable61=variable60xnew.replace(migratedWPSHome,presentWPSHome);
				trace("original value:"+variable60xnew);
				trace("replaced value:"+variable61);
			else: 
				variable61=variable60x;
			#endIf
		#endIf
	else:
		variable61=variable60x;
	#endIf
	
	trace("Value being returned " + variable61);
	trace("****************convertPathFrom6xTo70() end****************");
	return variable61;
#endDef

#-------------------------------------------------------------------------------------------------------------------------
# Updates variables in the given scope which have the 'source_install' in the value and replaces it with 'WAS_INSTALL_ROOT'
#-------------------------------------------------------------------------------------------------------------------------
def replaceOldInstallRoot (oldInstall,cellName,nodeName,serverName, clusterName):
	global AdminConfig;
	
	trace("****************replaceOldInstallRoot() start****************");
	trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName + " ##clusterName:" + clusterName);
	oldInstall = oldInstall.replace("/",'\\')
	trace ("To parse for old install root value'" + oldInstall + "'");
	oldInstallWindows = oldInstall.replace('\\', "/");
	trace ("To parse for old install windows root value'" + oldInstall + "'");


	scopeId=getScopeId(cellName,nodeName,serverName, clusterName);
	variableLists = wsadminToList(AdminConfig.list("VariableMap",scopeId));
	for eachList in variableLists :
		entries = wsadminToList(AdminConfig.list("VariableSubstitutionEntry", eachList));
		for entry in entries:
			# get exact variable which is only located in  cell ,node or server level.
			entry=getExactScopeId(entry,cellName,nodeName,serverName, clusterName);
			
			if ( entry!=""):
				variableValue = AdminConfig.showAttribute(entry, "value");
				if(variableValue != None and variableValue != '' and variableValue.find(oldInstall)!=-1):
					variableName = AdminConfig.showAttribute(entry, "symbolicName");
					trace ("Found variable " + variableName + " with oldInstallRoot value '" + str(variableValue) + "'");
					trace ("Variable:"+entry);
					newValue=convertPathFrom6xTo70(variableValue);
					attribute=[['value', newValue]];
					trace ("Updating " + variableName + " to replace " + oldInstall + "with " + newValue );
					AdminConfig.modify(entry, attribute);
					AdminConfig.save();
				#endIf
				if(variableValue != None and variableValue != '' and variableValue.find(oldInstallWindows)!=-1):
					variableName = AdminConfig.showAttribute(entry, "symbolicName");
					trace ("Found variable " + variableName + " with oldInstallRoot value '" + str(variableValue) + "'");
					trace ("Variable:"+entry);
					newValue=convertPathFrom6xTo70(variableValue);
					attribute=[['value', newValue]];
					trace ("Updating " + variableName + " to replace " + oldInstall + "with " + newValue );
					AdminConfig.modify(entry, attribute);
					AdminConfig.save();
				#endIf
			#endIf
		#endFor
	#endFor
trace("****************replaceOldInstallRoot() end****************");
#endDef


#-------------------------------------------------------------------------------------------------------------------------
# Updates variables in the given scope which have the 'source_install' in the value and replaces it with 'WAS_INSTALL_ROOT'
#-------------------------------------------------------------------------------------------------------------------------
def replaceOldProfileRoot (oldProfileRoot,cellName,nodeName,serverName, clusterName):
	global AdminConfig;
	
	trace("****************replaceOldProfileRoot() start****************");
	trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName+ "##clusterName" + clusterName);
	oldProfileRoot = oldProfileRoot.replace("/",'\\')
	trace ("To parse for old profile root value'" + oldProfileRoot + "'");
	oldProfileRootWindows = oldProfileRoot.replace('\\', "/");
	trace ("To parse for old profile windows root value'" + oldProfileRootWindows + "'");


	scopeId=getScopeId(cellName,nodeName,serverName, clusterName);
	variableLists = wsadminToList(AdminConfig.list("VariableMap",scopeId));
	for eachList in variableLists :
		entries = wsadminToList(AdminConfig.list("VariableSubstitutionEntry", eachList));
		for entry in entries:
			# get exact variable which is only located in  cell ,node or server level.
			entry=getExactScopeId(entry,cellName,nodeName,serverName, clusterName);
			
			if ( entry!=""):
				variableValue = AdminConfig.showAttribute(entry, "value");
				if(variableValue != None and variableValue != '' and variableValue.find(oldProfileRoot)!=-1):
					variableName = AdminConfig.showAttribute(entry, "symbolicName");
					trace ("Found variable " + variableName + " with oldProfileRoot value '" + str(variableValue) + "'");
					trace ("Variable:"+entry);
					newValue=convertProfilePathFrom6xTo70(variableValue);
					attribute=[['value', newValue]];
					trace ("Updating " + variableName + " to replace " + oldProfileRoot + "with " + newValue );
					AdminConfig.modify(entry, attribute);
					AdminConfig.save();
				#endIf
				if(variableValue != None and variableValue != '' and variableValue.find(oldProfileRootWindows)!=-1):
					variableName = AdminConfig.showAttribute(entry, "symbolicName");
					trace ("Found variable " + variableName + " with oldProfileRootWindows value '" + str(variableValue) + "'");
					trace ("Variable:"+entry);
					newValue=convertProfilePathFrom6xTo70(variableValue);
					attribute=[['value', newValue]];
					trace ("Updating " + variableName + " to replace " + oldProfileRootWindows + "with " + newValue );
					AdminConfig.modify(entry, attribute);
					AdminConfig.save();
				#endIf
			#endIf
		#endFor
	#endFor
trace("****************replaceOldProfileRoot() end****************");
#endDef


#-----------------------------------------------------------------
# Returns  id of the environment variable
#-----------------------------------------------------------------
def getVariableMapIds (variableName,cellName,nodeName,serverName, clusterName):
	global AdminConfig;
	
	variableMapIds=[];
	trace("****************getVariableMapIds() start****************");
	trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName + "##clusterName" + clusterName);
	trace ("To parse environment variable '" + variableName + "'");
	
	scopeId=getScopeId(cellName,nodeName,serverName, clusterName);
	variableLists = wsadminToList(AdminConfig.list("VariableMap",scopeId));
	for eachList in variableLists :
		entries = wsadminToList(AdminConfig.list("VariableSubstitutionEntry", eachList));
		for entry in entries:
			# get exact variable which is only located in  cell ,node or server level.
			entry=getExactScopeId(entry,cellName,nodeName,serverName, clusterName);
			
			if ( entry!="" and AdminConfig.showAttribute(entry, "symbolicName") == variableName):
				variableValue = AdminConfig.showAttribute(entry, "value");
				trace ("The value of " + variableName + " is '" + str(variableValue) + "'");
				trace ("VariableMapId:"+entry);
				variableMapIds.append(entry);
			#endIf
		#endFor
	#endFor
	trace("****************getVariableMapIds() end****************");
	return variableMapIds;
#endDef


#---------------------------------------------------------------------------------------------------------------------------------------------------------
#  set a WebSphere environment variable
#---------------------------------------------------------------------------------------------------------------------------------------------------------
def setVariableValue(variableName,variableValue,cellName,nodeName,serverName, clusterName):
	trace("****************setVariableValue() start****************");
	trace("variableName:" + variableName + " variableValue:"+str(variableValue));

	try:
		global AdminConfig;
		trace ("Scope: ##cellName:"+cellName+" ##nodeName:"+nodeName+" ##serverName:"+serverName+ "##clusterName:" + clusterName);
		trace ("##name:"+variableName+" ##value:"+str(variableValue));
		
		varMapIds = getVariableMapIds (variableName,cellName,nodeName,serverName, clusterName);
		if(len(varMapIds)!=0):
			for varMap in varMapIds:
				trace ("##varMapId being modified:"+varMap + "with value " + variableValue);
				attribute=[['value', variableValue]];
				AdminConfig.modify(varMap, attribute);
				AdminConfig.save();
			#endFor
			trace("****************setVariableValue() end****************");
			return 1;
		#endIf
		trace("****************setVariableValue() end****************");
		return 0;
	except:
		print "Error during setVariableValue():", sys.exc_info();
		trace("****************setVariableValue() end****************");
		return 0;
	#endTry
#endDef

def updateWBIVariables():
	trace("****************updateWBIVariable() start****************");

	cellName = getCellName();
	nodeName=getNodeName();
	serverName='';

	wbi_variable='WBI_INSTALL_ROOT';
	wbi_variable_value="${WAS_INSTALL_ROOT}";

	global AdminConfig;
	scopeId=getScopeId(cellName,nodeName,serverName);
	trace("scopeId:"+scopeId);
	
	mapList=wsadminToList(AdminConfig.list("VariableMap", scopeId));
	
	filteredMapList=[];
	for item in mapList:
		item=getExactScopeId(item,cellName,nodeName,serverName);
		trace("item:"+item);
		if ( not item==""):
			filteredMapList.append(item);
	#endFor
	
	map =filteredMapList[0];	
	trace("VariableMap id:"+map);
	# check if WBI_INSTALL_ROOT variable exists in specified scope. 
	# 1. if exists, update the value of the variable
	trace("Trying to update WBI_INSTALL_ROOT variable");
	varMapIds = getVariableMapIds (wbi_variable,cellName,nodeName,serverName);
	if(len(varMapIds) > 0):
		setVariableValue(wbi_variable,wbi_variable_value,cellName,nodeName,serverName);
	else:
		pass;
	#endIf

	trace("****************updateWBIVariable() end****************");
#endDef

def updateDerbyDataSourceProperties():
	trace("****************updateDataSourceProperties() start****************");
	
	dataSourceId="";
	providerType="Derby JDBC Provider";
	providerType1="Derby JDBC Provider (XA)";
	providerType2="Cloudscape JDBC Provider";
	providerType3="Cloudscape JDBC Provider (XA)";

	
	global AdminConfig;
	dataSourceList=AdminConfig.list("DataSource")
	dataSources = wsadminToList(dataSourceList);
	for id in dataSources:
		curAttVal1=AdminConfig.showAttribute(id,"providerType");
		trace(AdminConfig.showAttribute(id,"providerType"));
		if((curAttVal1==providerType) or (curAttVal1==providerType1) or (curAttVal1==providerType2) or (curAttVal1==providerType3)):
			name = AdminConfig.showAttribute(id, "name");
			trace("provideType with Debry found" + name);
			propSet = AdminConfig.showAttribute(id,"propertySet")
			resoucepropertiesList = wsadminToList(AdminConfig.list("J2EEResourceProperty", propSet))
			for propid in resoucepropertiesList:
				curPropName=AdminConfig.showAttribute(propid,"name");
				if (curPropName=="databaseName"):
					trace("original propertyValue:"+AdminConfig.showAttribute(propid,"value"));
					existingValue = AdminConfig.showAttribute(propid,"value");
					#find the old profile value
					index = existingValue.find("databases");
					if (index != -1):
						str = existingValue[index:len(existingValue)]
						trace("string value to be added is " + str);
						newValue = "${USER_INSTALL_ROOT}/" + str;				
						trace("updated propertyValue:"+newValue);	
						properties = [["value", newValue]];
						AdminConfig.modify(propid, properties)
						AdminConfig.save()
					#endIf
				#endIf
			#endFor
		#endIf
	#endFor
	trace("****************updateDataSourceProperties() end****************");
#endif

def updateAllOracleDataSource():
	trace("****************updateAllOracleDataSources() start****************");
	
	dataSourceId="";
	providerType="Oracle JDBC Driver";
	providerType1="Oracle JDBC Driver (XA)";
	
	global AdminConfig;
	dataSourceList=AdminConfig.list("DataSource")
	dataSources = wsadminToList(dataSourceList);
	for id in dataSources:
		curAttVal1=AdminConfig.showAttribute(id,"providerType");
		if((curAttVal1==providerType) or (curAttVal1==providerType1)):
			name = AdminConfig.showAttribute(id, "name");
			trace("provideType with Oracle found" + name);
			provider=AdminConfig.showAttribute(id,"provider");
			trace("After provider" + AdminConfig.showAttribute(provider, "name"));
			print AdminConfig.showAttribute(provider, "classpath");
			newClasspath="${ORACLE_JDBC_DRIVER_PATH}/ojdbc6.jar";
			trace("new classpath being set" + newClasspath);	
			attributes=[["classpath",newClasspath]];
			AdminConfig.modify(provider, attributes );
			AdminConfig.save();

			curPropName=AdminConfig.showAttribute(id,"datasourceHelperClassname");
			properties = [["datasourceHelperClassname", "com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper"]];
			trace("original propertyValue:"+AdminConfig.showAttribute(id,"datasourceHelperClassname"));
			trace("updated propertyValue:"+"com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper");	
			AdminConfig.modify(id, properties)
			AdminConfig.save()
		#endIf
	#endFor
	
	trace("****************updateAllOracleDataSources() end****************");
#endDef


def updateAllSQLServerDataSource():
	trace("****************updateAllSQLServerDataSource() start****************");
	
	dataSourceId="";
	providerType="SQLServer";
	
	global AdminConfig;
	dataSourceList=AdminConfig.list("DataSource")
	dataSources = wsadminToList(dataSourceList);
	for id in dataSources:
		curAttVal1=AdminConfig.showAttribute(id,"providerType");
		if(curAttVal1==providerType):
			name = AdminConfig.showAttribute(id, "name");
			trace("provideType with Oracle found" + name);
			provider=AdminConfig.showAttribute(id,"provider");
			newClasspath="${MICROSOFT_JDBC_DRIVER_PATH}/sqljdbc.jar";
			trace("new classpath being set" + newClasspath);	
			attributes = [["classpath",newClasspath]];
			AdminConfig.modify(id, attributes );
			AdminConfig.save();

			curPropName=AdminConfig.showAttribute(id,"datasourceHelperClassname");
			properties = [["datasourceHelperClassname", "com.ibm.websphere.rsadapter.MicrosoftSQLServerDataStoreHelper"]];
			trace("original propertyValue:"+AdminConfig.showAttribute(id,"datasourceHelperClassname"));
			trace("updated propertyValue:"+"com.ibm.websphere.rsadapter.MicrosoftSQLServerDataStoreHelper");	
			AdminConfig.modify(id, properties)
			AdminConfig.save()
		#endIf
	#endFor
	
	trace("****************updateAllSQLServerDataSources() end****************");
#endDef

def createVariable(variableName,variableValue,cellName,nodeName,serverName, clusterName):
	trace("****************createVariable() start****************");
	
	global AdminConfig;
	scopeId=getScopeId(cellName,nodeName,serverName, clusterName);
	trace("scopeId:"+scopeId);
	
	mapList=wsadminToList(AdminConfig.list("VariableMap", scopeId));
	
	filteredMapList=[];
	for item in mapList:
		trace("item:"+item);
		item=getExactScopeId(item,cellName,nodeName,serverName, clusterName);
		trace("item:"+item);
		if ( not item==""):
			filteredMapList.append(item);
	#endFor
	
	map =filteredMapList[0];	
	trace("VariableMap id:"+map);
	trace("variableName:" + variableName + " variableValue:"+str(variableValue));
	
	# check if the variable exists in specified scope. 
	# 1. if exists, update the value of the variable
	# 2. if not exists, create  the variable.
	varMapIds = getVariableMapIds (variableName,cellName,nodeName,serverName, clusterName);
	if(len(varMapIds) > 0):
		setVariableValue(variableName,variableValue,cellName,nodeName,serverName, clusterName);
	elif (not len(map)==0):
		name = ["symbolicName", variableName];
		value = ["value", variableValue];
		attrs = [name, value];
		
		# create WAS variable.
		AdminConfig.create("VariableSubstitutionEntry", map, attrs );
		AdminConfig.save( );
	else:
		pass;
	#endIf
	
	trace("****************createVariable() end****************");
#endif

#-----------------------------------------------------------------
# Main program:
#-----------------------------------------------------------------
def main():
	print 'Executing migration common script.'
	#System.setProperty("bpm.upgrade.previous.profileName", "Dmgr01");
	#System.setProperty("wbi.upgrade.node.type", "dmgr");
	#System.setProperty("wbi.upgrade.backup.dir", "c:/Procbcup");
	#System.setProperty("wbi.upgrade.previous.version", "6.2.0.3");

	serverName='';
	clusterName=System.getProperty("bpm.upgrade.cluster.name");
	if(clusterName):
		trace(clusterName)
	else:
		clusterName = ''
	#endIf
	clusterStamp=System.getProperty("bpm.upgrade.cluster.stamp");
	previousVersion = getPropertyValue('wbi.upgrade.previous.version')
	
	if (clusterStamp != "true"):
		migratedWPSHome=normalizePath(getMigratedWASHome());
		migratedWPSHome=migratedWPSHome.replace('\\',"/");
		migratedProfileHome=normalizePath(getMigratedProfileHome());
		migratedProfileHome=migratedProfileHome.replace('\\',"/");
	#endIf	
	cellName=getCellName();
	nodeType=getNodeType();


	if ( nodeType == 'managed' or nodeType == 'unmanaged' ):
		# standalone profile and custom profile
		nodeName=getNodeName();
		createVariable("MIGRATION_VERSION", previousVersion, cellName, nodeName, serverName, clusterName);
	else:
		# dmgr profile
		nodeName='';
		if (clusterStamp != "true"):
			trace("Calling replaceOldInstallRoot at cell level for oldInstall value: " + migratedWPSHome);
			replaceOldProfileRoot(migratedProfileHome,cellName,nodeName,serverName, clusterName);
			replaceOldInstallRoot(migratedWPSHome,cellName,nodeName,serverName, clusterName);
			# set the node name to the actual value again to call replace for node level variables
			nodeName=getNodeName();
			#reset the version to previous value
			if (clusterName != ''):
				createVariable("MIGRATION_VERSION", previousVersion, cellName, nodeName, serverName, clusterName);
			#create the variable for each cluster in dmgr
			else:
				createVariable("MIGRATION_VERSION", previousVersion, cellName, nodeName, serverName, clusterName);
				clusterList = wsadminToList(AdminConfig.list("ServerCluster"))
				for cluster in clusterList:
					print "Cluster is ", cluster
					name = AdminConfig.showAttribute(cluster, "name")
					print "Name is", name
					createVariable("MIGRATION_VERSION", previousVersion, cellName, nodeName, serverName, name);
				#endFor
			#endFor
		#endIf
		#Just create the variable when called for cluster stamping
		if (clusterStamp == "true"):
			nodeName=getNodeName();
			createVariable("MIGRATION_VERSION", "7.5.0.0", cellName, nodeName, serverName, clusterName);
			return;
		#endIf
	#endIf

	trace("Calling replaceOldInstallRoot at node level for oldInstall value: " + migratedWPSHome);
	replaceOldInstallRoot(migratedWPSHome,cellName,nodeName,serverName,clusterName);
	print 'Done replacing old install values.'

	if (getNodeType() != 'managed'):
		updateAllOracleDataSource();
	#endIf

	trace("getNodeType() " + getNodeType());
	if (getNodeType() == 'unmanaged'):
		updateDerbyDataSourceProperties();
	#endIf
	#updateAllSQLServerDataSource();


	previousVersion = getPropertyValue('wbi.upgrade.previous.version')
	if (previousVersion.find('6.0.2')>=0):
		print 'Found 602 source profile. Trying to update variables.'
		updateWBIVariables();
		print 'Updated wbi variable. Successfully exiting migration common script.'
		return 0
	else:
		print 'Not a 602 source profile. No additional updates needed. Successfully exiting migration common script.'
		return 0
	#endIf
	
#endDef


#-----------------------------------------------------------------
# Start Main function
#-----------------------------------------------------------------
main();
#-----------------------------------------------------------------
# End Main function
#-----------------------------------------------------------------