#************************************************************************
# Licensed Materials - Property of IBM
# 5724-M24
# Copyright IBM Corporation 2009, 2010.  All rights reserved.
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#************************************************************************

###########################################################################
# Run the wbmConfigureQueueBypassDatasource admin task to create the
# data source that enables the remote CEI event service to use 
# Queue Bypass to route events to the WebSphere Business Monitor database. 
# The data source will be named Monitor_<monitorCellName>_Routing_Database.
#
# This script must run on the remote standalone server or 
# the remote deployment manager. Do not run this script on
# the WebSphere Business Monitor server.
#
# If the remote standalone server or the remote deployment manager
# is not running on WebSphere Process Server v7, copy 
# monitorCommunicationWithWASnnBasedCells.zip (or .tar) from
# <Monitor_profile_home>/scripts.wbm/crossCell to the <WAS_home>/plugins
# directory on the remote system and extract the contents. 
# Do the extract before running this script.
# "WASnn" is "WAS70" for WebSphere Application Server v7.0, or 
# "WAS61" for WebSphere Application Server v6.1, or 
# "WAS60" for WebSphere Application Server v6.0.
###########################################################################

# Example: Running this script on Windows
#   <PROFILE_DIR>\bin\wsadmin.bat 
#    -lang jython 
#    -f "<path_to_script>/configureQueueBypass.py" 

# Example: Running this script on Unix/Linux
#   <PROFILE_DIR>/bin/wsadmin.sh 
#    -lang jython
#    -f "<path_to_script>/configureQueueBypass.py" 

# Turn on tracing if needed
print AdminControl.trace('com.ibm.wbimonitor.*=all=enabled')

##################################################################
# Set the values for the parameters
##################################################################
# monitorCell - The name of the cell where WebSphere Business Monitor is installed.
cellName = 'myMonitorCellname'
# databaseType - The database type for the Monitor database. Specify 'db2', 'oracle' or 'sqlserver'.
dbType = 'db2'
# jdbcProvider - The name of an existing JDBC provider that supports the database type.
# The JDBC provider must be defined at the cell scope.
jdbcProvider = 'myProvider'
# driverType - Specify either 2 or 4, for DB2 or Oracle.
# For an Oracle database, use 2 for the OCI driver and 4 for the Thin driver.
# Not used for SQL Server.
driverType = '4'
# databaseName - The name of the WebSphere Business Monitor database.
dbName = 'myMonitorDatabase'
# databaseServerName - The host name of the database server.
dbServerName = 'myhost.ibm.com'
# databaseServerPort - The port for the database server.
dbServerPort = '50000'
# Security information - Specify either an existing authentication alias
# or the user name and password for the database. 
# If user name and password are specified, an authentication alias named 
# MonitorRoutingDatabaseAlias_<monitorCellName> will be created.
# Choose one of the 2 formats shown and uncomment the line
#securityParm = '-authAlias myAuthAlias'
#securityParm = '-user myUserName -password myPassword'

##################################################################
# Run the admin task using the parameters defined above
##################################################################
AdminTask.wbmConfigureQueueBypassDatasource(['-monitorCell', cellName, \
  '-databaseType', dbType, '-jdbcProvider', jdbcProvider, \
  '-driverType', driverType, '-databaseName', dbName, \
  '-databaseServerName', dbServerName, '-databaseServerPort', dbServerPort, \
  securityParm])

##################################################################
# Save the changes
##################################################################
AdminConfig.save()
